//
//  ViewController.m
//  TwoColumnGridFromTwoDataSources
//
//  Created by Stephen Zaharuk on 1/7/15.
//  Copyright (c) 2015 Infragistics. All rights reserved.
//

#import "ViewController.h"

@interface ViewController ()
{
    IGGridView* _gridView;
    IGGridViewDataSourceHelper* _dsh;
}

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    _gridView = [[IGGridView alloc]initWithFrame:self.view.bounds];
    _gridView.headerHeight = 0;
    _gridView.autoresizingMask = UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleWidth;
    [self.view addSubview:_gridView];
    
    NSArray* fields = @[@"First Name", @"Last Name", @"Street", @"City", @"State", @"Zip" ];
    NSArray* values = @[@"Tim", @"Smith", @"112 5th Ave", @"Seattle", @"WA", @98119];
    
    NSMutableArray* data = [[NSMutableArray alloc]init];
    for(NSInteger i = 0;i  < fields.count; i++)
    {
        CombinedObject* obj = [[CombinedObject alloc]init];
        obj.sortOrder = i;
        obj.fieldLabel = fields[i];
        obj.value = values[i];
        [data addObject:obj];
    }
    
    _dsh = [[IGGridViewDataSourceHelper alloc]init];
    _dsh.autoGenerateColumns = NO;
    [_dsh.columnDefinitions addObject:[[IGGridViewColumnDefinition alloc]initWithKey:@"fieldLabel"]];
    [_dsh.columnDefinitions addObject:[[IGGridViewColumnDefinition alloc]initWithKey:@"value"]];
    [_dsh.columnDefinitions addObject:[[CustomColumn alloc]initWithKey:@"sortOrder"]];
    _dsh.data = data;
    
    _gridView.dataSource = _dsh;
}


@end

@implementation CombinedObject


@end


@implementation CustomColumn

-(IGGridViewCell *)gridView:(IGGridView *)gridView createCell:(IGCellPath *)path usingDataSource:(IGGridViewDataSourceHelper *)dataSource
{
    CustomCell* cell = [gridView dequeueReusableCellWithIdentifier:@"CustomCell"];
    if(!cell)
    {
        cell = [[CustomCell alloc]initWithReuseIdentifier:@"CustomCell"];
    }
    
    NSObject* data = [dataSource resolveDataValueForCell:path]; // Gets the value to be displayed in the cell.  use this to set up whats displayed in the cell.
    
    
    return cell;
    
}

@end

@interface CustomCell()
{
    UISlider* _slider;
}

@end

@implementation CustomCell

-(id)init
{
    self = [super init];
    
    if(self)
    {
        _slider = [[UISlider alloc]init];
        [self addSubview:_slider];
    }
    
    return self;
}

-(void)setupSize:(CGSize)size
{
    [super setupSize:size];
    
    _slider.frame = CGRectMake(0,0, size.width, size.height);
}

@end
